==> johnny-fetch-1.0.3.tgz: package/src/fetcher-con-token-autent.js <==
"use strict";
require('es6-shim');
/**
 * Decorador de un fetcher que agrega un token de autenticación en el encabezado
 * "Authorization" de los requerimientos.
 */
var FetcherConTokenAutent = (function () {
    function FetcherConTokenAutent(fetcherDecorar, opciones) {
        this.fetcherDecorar = fetcherDecorar;
        this.opciones = opciones;
        if (!fetcherDecorar) {
            throw new TypeError('No se ha indicado el fetcher a decorar');
        }
        var tokenType;
        if (!opciones || (tokenType = typeof opciones.token) !== 'string' && tokenType !== 'function') {
            throw new TypeError('Debe indicarse un toke o función para obtener el token a incluír en el encabezado de los requerimientos.');
        }
    }
    FetcherConTokenAutent.prototype.fetchJson = function (url, init) {
        var _this = this;
        return this.asegurarHeader(init).then(function (init) {
            return _this.fetcherDecorar.fetchJson(url, init);
        });
    };
    FetcherConTokenAutent.prototype.fetchText = function (url, init) {
        var _this = this;
        return this.asegurarHeader(init).then(function (init) {
            return _this.fetcherDecorar.fetchText(url, init);
        });
    };
    FetcherConTokenAutent.prototype.fetchResponseOk = function (url, init) {
        var _this = this;
        return this.asegurarHeader(init).then(function (init) {
            return _this.fetcherDecorar.fetchResponseOk(url, init);
        });
    };
    /**
     * Devuelve una promesa que se resuelve con el token de autenticación a incluír en los
     * requerimientos.
     */
    FetcherConTokenAutent.prototype.token = function () {
        var _this = this;
        return Promise.resolve().then(function () {
            var opcionToken = _this.opciones.token;
            var valor = (typeof opcionToken === 'function') ? opcionToken() : opcionToken;
            return valor;
        });
    };
    FetcherConTokenAutent.prototype.asegurarHeader = function (init) {
        return this.token().then(function (t) {
            if (!t) {
                return init;
            }
            var valorHeader = 'Bearer ' + t;
            if (!init) {
                init = {};
            }
            if (!init.headers) {
                init.headers = {};
            }
            if (init.append) {
                init.append('Authorization', valorHeader);
            }
            else {
                init.headers.Authorization = valorHeader;
            }
            return init;
        });
    };
    return FetcherConTokenAutent;
}());
exports.FetcherConTokenAutent = FetcherConTokenAutent;

==> johnny-fetch-1.0.5.tgz: package/src/fetcher-con-token-autent.js <==
"use strict";
require('es6-shim');
/**
 * Decorador de un fetcher que agrega un token de autenticación en el encabezado
 * "Authorization" de los requerimientos.
 */
var FetcherConTokenAutent = (function () {
    function FetcherConTokenAutent(fetcherDecorar, opciones) {
        this.fetcherDecorar = fetcherDecorar;
        this.opciones = opciones;
        if (!fetcherDecorar) {
            throw new TypeError('No se ha indicado el fetcher a decorar');
        }
        var tokenType;
        if (!opciones || (tokenType = typeof opciones.token) !== 'string' && tokenType !== 'function') {
            throw new TypeError('Debe indicarse un token o función para obtener el token a incluír en el encabezado de los requerimientos.');
        }
    }
    FetcherConTokenAutent.prototype.fetchJson = function (url, init) {
        var _this = this;
        return this.asegurarHeader(init).then(function (init) {
            return _this.fetcherDecorar.fetchJson(url, init);
        });
    };
    FetcherConTokenAutent.prototype.fetchText = function (url, init) {
        var _this = this;
        return this.asegurarHeader(init).then(function (init) {
            return _this.fetcherDecorar.fetchText(url, init);
        });
    };
    FetcherConTokenAutent.prototype.fetchBlob = function (url, init) {
        var _this = this;
        return this.asegurarHeader(init).then(function (init) {
            return _this.fetcherDecorar.fetchBlob(url, init);
        });
    };
    FetcherConTokenAutent.prototype.fetchResponseOk = function (url, init) {
        var _this = this;
        return this.asegurarHeader(init).then(function (init) {
            return _this.fetcherDecorar.fetchResponseOk(url, init);
        });
    };
    /**
     * Devuelve una promesa que se resuelve con el token de autenticación a incluír en los
     * requerimientos.
     */
    FetcherConTokenAutent.prototype.token = function () {
        var _this = this;
        return Promise.resolve().then(function () {
            var opcionToken = _this.opciones.token;
            var valor = (typeof opcionToken === 'function') ? opcionToken() : opcionToken;
            return valor;
        });
    };
    FetcherConTokenAutent.prototype.asegurarHeader = function (init) {
        return this.token().then(function (t) {
            if (!t) {
                return init;
            }
            var valorHeader = 'Bearer ' + t;
            if (!init) {
                init = {};
            }
            if (!init.headers) {
                init.headers = {};
            }
            if (init.append) {
                init.append('Authorization', valorHeader);
            }
            else {
                init.headers.Authorization = valorHeader;
            }
            return init;
        });
    };
    return FetcherConTokenAutent;
}());
exports.FetcherConTokenAutent = FetcherConTokenAutent;
